from .death_report_extra_fields_model_mixin import DeathReportExtraFieldsModelMixin
from .death_report_model_mixin import DeathReportModelMixin
from .death_report_tmg_model_mixin import (
    DeathReportTmgModelMixin,
    DeathReportTmgSecondManager,
    DeathReportTmgSecondModelMixin,
    DeathReportTmgSecondSiteManager,
)
from .simple_death_report_model_mixin import SimpleDeathReportModelMixin
